# sd-jwt-python Fork with cryptojwt

## Introduction

This module is a fork of  [sd-jwt-python](https://github.com/openwallet-foundation-labs/sd-jwt-python) project. It has been adapted to use the [`cryptojwt`](https://github.com/IdentityPython/JWTConnect-Python-CryptoJWT) library as the core JWT implementation. 

If you're familiar with the original `sd-jwt-python` library, this fork retains similar functionality with minimal API changes, if needed.

---

---
